# Lindenmayer (L-systems)

L-systems were introduced and developed in 1968 by Aristid Lindenmayer, a
Hungarian theoretical biologist and botanist at the University of Utrecht.
Lindenmayer used L-systems to describe the behaviour of plant cells and to model
the growth processes of plant development. L-systems have also been used to
model the morphology of a variety of organisms and can be used to generate
self-similar fractals such as iterated function systems.

<img src="examples/plant.png" alt="plant" title="Plant" width="800" />
<img src="examples/branch.png" alt="branch" title="Branch" width="300" />
<img src="examples/penrose.png" alt="penrose" title="Penrose" width="300" />
<img src="examples/sierpinski-triangle.png" alt="sierpinski" title="Sierpinski" width="300" />
<img src="examples/peano-gosper.png" alt="peano-gosper" title="Peano-Gosper" width="300" />
<img src="examples/koch.png" alt="koch" title="Koch" width="300" />
<img src="examples/plant1.png" alt="plant1" title="Plant1" width="300" />
<img src="examples/hilbert_curve2.png" alt="hilbert_curve2" title="Hilbert Curve 2" width="300" />
<img src="examples/32segments.png" alt="32segments" title="32 segments" width="300" />
<img src="examples/simple.png" alt="simple" title="Simple" width="300" />
<img src="examples/peano.png" alt="peano" title="Peano" width="300" />
<img src="examples/hilbert.png" alt="hilbert" title="Hilbert" width="300" />
<img src="examples/dragon_curve.png" alt="dragon_curve" title="Dragon Curve" width="300" />
<img src="examples/quadratic_koch.png" alt="quadratic_koch" title="Quadratic Koch" width="300" />
<img src="examples/hilbert_curve.png" alt="hilbert_curve" title="Hilbert Curve" width="300" />

(Images generated by `../test/runtests.jl`, cropped, then converted to PNG.)

For more information, type

```
help?> LSystem
```

You define an L-System like this:

```
koch = LSystem(Dict("F" => "F+F--F+F"), "F")
```

This says: there's one rule; replace "F" with "F+F--F+F" for each iteration. And start off with an initial state consisting of just a single "F". The first iteration therefore draws four lines, and changes direction at the end of each but the last one. The length of the lines and the angle of the turn are specified when you evaluate the LSystem.

To evaluate and draw a Lindenmayer system, use functions like this:

```
drawLSystem(lsystem::LSystem)
drawLSystem(lsystem::LSystem, forward=30, turn=45, iterations=6)
drawLSystem(lsystem::LSystem, filename="/tmp/lsystem.pdf", showpreview=false)
```
